@@ -15,4 +15,11 @@ else:
     _query_builder = components.declare_component("streamlit_query_builder", path=build_dir)
 
 def query_builder(columns: list):
-    return _query_builder(columns)
\ No newline at end of file
+    fields = []
+    for c in columns:
+        if isinstance(c, str):
+            fields.append({'name': c, 'label' : c})
+        if isinstance(c, dict):
+            if 'name' in c and 'label' in c:
+                fields.append(c)
+    return _query_builder(fields=fields)
\ No newline at end of file
